Set routines
============

.. currentmodule:: numpy

Making proper sets
------------------
.. autosummary::
   :toctree: generated/

   unique1d

Boolean operations
------------------
.. autosummary::
   :toctree: generated/

   intersect1d
   intersect1d_nu
   setdiff1d
   setmember1d
   setxor1d
   union1d
